summaryrefslogtreecommitdiff
path: root/source3/smbd/reply.c
diff options
context:
space:
mode:
Diffstat (limited to 'source3/smbd/reply.c')
-rw-r--r--source3/smbd/reply.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/source3/smbd/reply.c b/source3/smbd/reply.c
index e1feb921f5..402f9db754 100644
--- a/source3/smbd/reply.c
+++ b/source3/smbd/reply.c
@@ -837,17 +837,16 @@ int reply_sesssetup_and_X(connection_struct *conn, char *inbuf,char *outbuf,int
fstrcpy(user,p);
p = skip_string(p,1);
/*
* Incoming user is in DOS codepage format. Convert
* to UNIX.
*/
dos_to_unix(user,True);
domain = p;
-
+ dos_to_unix(domain, True);
DEBUG(3,("Domain=[%s] NativeOS=[%s] NativeLanMan=[%s]\n",
domain,skip_string(p,1),skip_string(p,2)));
}
-
DEBUG(3,("sesssetupX:name=[%s]\n",user));
/* If name ends in $ then I think it's asking about whether a */
@@ -837,17 +837,16 @@ int reply_sesssetup_and_X(connection_struct *conn, char *inbuf,char *outbuf,int
p = skip_string(p,1);
/*
- * Incoming user is in DOS codepage format. Convert
+ * Incoming user and domain are in DOS codepage format. Convert
* to UNIX.
*/